@@ -1,7 +1,7 @@
 # ==============================================================================
 # imputation function using predictive mean matching
 # ==============================================================================
-mi.pmm <- function(formula, data = NULL, start = NULL, n.iter = 100, ... )
+mi.pmm <- function(formula, data = NULL, start = NULL, n.iter = 100, missing.index = NULL, ... )
 {
   call <- match.call()
   mf   <- match.call(expand.dots = FALSE)
@@ -13,6 +13,7 @@ mi.pmm <- function(formula, data = NULL, start = NULL, n.iter = 100, ... )
   mf <- eval(mf, parent.frame())
   mt <- attr(mf, "terms")
   Y  <- model.response(mf, "any")
+
   if (length(dim(Y)) == 1) {
     nm <- rownames(Y)
     dim(Y) <- NULL
@@ -20,21 +21,33 @@ mi.pmm <- function(formula, data = NULL, start = NULL, n.iter = 100, ... )
       names(Y) <- nm
     }
   }
+
   X <- mf[,-1,drop=FALSE]
-  namesD <- if(is.null(data)) {
-              NULL 
-            } 
-            else{ 
-              deparse(substitute(data)) 
-            }
-  mis    <- is.na( Y )
-  n.mis  <- sum( mis )
+#  namesD <- if(is.null(data)) {
+#              NULL 
+#            } 
+#            else{ 
+#              deparse(substitute(data)) 
+#            }
+
+  mis <- is.na(Y)
+  n.mis <- if(is.null(missing.index)){
+             sum(mis)
+           } else{
+             length(missing.index)
+           }
+  if(is.null(missing.index)& any(mis)){
+    missing.index <- mis
+  }
+
+
   if(is.null(data)){ 
     data <- mf 
   }
   if(!is.null(start)){
-    n.iter <- 30
+    n.iter <- 10
   }
+  
   bglm.imp  <- bayesglm( formula , start = start, n.iter = n.iter )
   yhat <- predict( bglm.imp , newdata = data.frame( Y, X ) ) 
   result <- new(c("mi.pmm", "mi.method"),
@@ -45,8 +58,8 @@ mi.pmm <- function(formula, data = NULL, start = NULL, n.iter = 100, ... )
   result@model$coefficients <- bglm.imp$coefficients
   result@model$sigma <- sigma.hat( bglm.imp )
   result@expected <- yhat
-  result@random   <- apply( as.array( yhat[mis] ), 1, 
-                              mi.pmm.match, yhat=yhat[!mis], Y=Y[!mis] ) 
+  result@random   <- apply( as.array( yhat[missing.index] ), 1, 
+                              mi.pmm.match, yhat=yhat[!missing.index], Y=Y[!missing.index] ) 
   result@residuals <- bglm.imp$residuals
   return(result)
 }
